kubernetes

package
v0.0.0-...-6739181 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ClientCertificateData

func ClientCertificateData(ctx context.Context, k8sClient *kubernetes.Clientset, username string, userPrivateKey any) ([]byte, error)

ClientCertificateData creates a client certificate for the given cluster and private key. This is used to to authenticate to the cluster.

func SetUserRole

func SetUserRole(ctx context.Context, k8sClient *kubernetes.Clientset, username string, roleName string) error

SetUserRole sets the role for the given user.

Types

This section is empty.

Jump to