Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClientCertificateData ¶
func ClientCertificateData(ctx context.Context, k8sClient *kubernetes.Clientset, username string, userPrivateKey any) ([]byte, error)
ClientCertificateData creates a client certificate for the given cluster and private key. This is used to to authenticate to the cluster.
func SetUserRole ¶
func SetUserRole(ctx context.Context, k8sClient *kubernetes.Clientset, username string, roleName string) error
SetUserRole sets the role for the given user.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.